@@ -7,7 +7,7 @@ package IO::Async::ChildManager;
 
 use strict;
 
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 
 # Not a notifier
 
@@ -167,7 +167,7 @@ sub SIGCHLD
  
       if( defined $handlermap->{$zid} ) {
          $handlermap->{$zid}->( $zid, $? );
-         undef $handlermap->{$zid};
+         delete $handlermap->{$zid};
       }
       else {
          carp "No child death handler for '$zid'";
@@ -210,6 +210,96 @@ sub watch
    return;
 }
 
+=head2 $watching = $manager->is_watching( $kid )
+
+This method tests if the manager is currently watching for termination of the
+given PID. It returns a boolean value.
+
+=over 8
+
+=item $kid
+
+The PID.
+
+=back
+
+=cut
+
+sub is_watching
+{
+   my $self = shift;
+   my ( $kid ) = @_;
+
+   my $handlermap = $self->{childdeathhandlers};
+
+   return exists $handlermap->{$kid};
+}
+
+=head2 @kids = $manager->list_watching()
+
+This method returns a list of the PIDs that the manager is currently watching
+for. The list is returned in no particular order.
+
+=cut
+
+sub list_watching
+{
+   my $self = shift;
+
+   my $handlermap = $self->{childdeathhandlers};
+
+   return keys %$handlermap;
+}
+
+=head2 $pid = $manager->detach_child( %params )
+
+This method creates a new child process to run a given code block.
+
+=over 8
+
+=item code => CODE
+
+A block of code to execute in the child process. It will be called in scalar
+context inside an C<eval> block. The return value will be used as the
+C<exit()> code from the child if it returns (or 255 if it returned C<undef> or
+thows an exception).
+
+=item on_exit => CODE
+
+A optional callback function to be called when the child processes exits. It
+will be invoked in the following way:
+
+ $on_exit->( $pid, $exitcode )
+
+This key is optional; if not supplied, the calling code should install a
+handler using the C<watch_child()> method.
+
+=cut
+
+sub detach_child
+{
+   my $self = shift;
+   my %params = @_;
+
+   my $code = $params{code};
+
+   my $kid = fork();
+   defined $kid or croak "Cannot fork() - $!";
+
+   if( $kid == 0 ) {
+      my $exitvalue = eval { $code->() };
+
+      defined $exitvalue or $exitvalue = -1;
+      _exit( $exitvalue );
+   }
+
+   if( defined $params{on_exit} ) {
+      $self->watch( $kid => $params{on_exit} );
+   }
+
+   return $kid;
+}
+
 =head2 $pid = $manager->spawn( %params )
 
 This method creates a new child process to run a given code block or command.
@@ -303,19 +393,17 @@ sub spawn
       };
    }
 
-   my $kid = fork();
-   defined $kid or croak "Cannot fork() - $!";
+   my $kid = $self->detach_child( 
+      code => sub {
+         # Child
+         close( $readpipe );
+         $self->_spawn_in_child( $writepipe, $code, \@setup );
+      },
+   );
 
-   if( $kid != 0 ) {
-      # Parent
-      close( $writepipe );
-      $self->_spawn_in_parent( $readpipe, $kid, $on_exit );
-   }
-   else {
-      # Child
-      close( $readpipe );
-      $self->_spawn_in_child( $writepipe, $code, \@setup );
-   }
+   # Parent
+   close( $writepipe );
+   return $self->_spawn_in_parent( $readpipe, $kid, $on_exit );
 }
 
 =head2 C<setup> array
@@ -565,14 +653,13 @@ sub _spawn_in_child
       $code->();
    };
 
-   defined $exitvalue or $exitvalue = -1;
-
    my $writebuffer = "";
    $writebuffer .= pack( "I", $!+0 );
    $writebuffer .= pack( "I", length( $@ ) ) . $@;
 
    syswrite( $writepipe, $writebuffer );
-   _exit( $exitvalue );
+
+   return $exitvalue;
 }
 
 # Keep perl happy; keep Britain tidy
